@@ -20,6 +20,7 @@ from pi_touch_gui._utilities import backlog_error
 from pi_touch_gui._widget_bases import IWidget, IWidgetInterface
 from pi_touch_gui.colors import BLACK
 from pi_touch_gui.multitouch.raspberrypi_ts import Touchscreen, TS_RELEASE
+from widget_buttons import Button
 
 LOG = logging.getLogger(__name__)
 
@@ -532,7 +533,10 @@ class GUI(object):
                             if event.key in [K_SPACE, K_RETURN]:
                                 if page.is_focused():
                                     new_page = page.release_widget()
-                                    page.focus_widget(False)
+                                    widget = page._focus_widget
+                                    if (isinstance(widget, Button)
+                                            and widget.behavior != Button.HOLD):
+                                        page.focus_widget(False)
                                 else:
                                     page.focus_widget(True)
 
