@@ -285,5 +285,5 @@ class Graph(IWidget):
                         textpos.centery = prev_y
                     surface.blit(text, textpos)
 
-        if self._focus:
-            self.render_focus(surface)
+    def can_focus(self):
+        return False
